#!/usr/bin/python

import sys


package_name = "telepathy-qt4-1"
package_dir = "/usr/share/%s-tests" % package_name

non_dbus_tests_env = \
    "XDG_DATA_HOME=%s XDG_DATA_DIRS=%s abs_top_srcdir=%s" \
    % (package_dir, package_dir, package_dir)
non_dbus_tests = ["test-key-file", "test-manager-file", "test-profile", "test-ptr", "test-utils"]

dbus_tests_env = \
    "XDG_DATA_HOME=%s XDG_DATA_DIRS=%s sh %s/with-session-bus.sh " \
    "--config-file=%s/dbus-1/session.conf --" % \
    (package_dir, package_dir, package_dir, package_dir)

dbus_tests = [
    "dbus/test-account-basics",
    "dbus/test-account-channel-dispatcher",
    "dbus/test-account-connection-factory",
    "dbus/test-chan-basics",
    "dbus/test-chan-conference",
    "dbus/test-chan-contact-search",
    "dbus/test-chan-group",
    "dbus/test-client",
    "dbus/test-client-factories",
    "dbus/test-cm-basics",
    "dbus/test-conn-basics",
    "dbus/test-conn-capabilities",
    "dbus/test-conn-introspect-cornercases",
    "dbus/test-conn-requests",
    "dbus/test-conn-roster",
    "dbus/test-conn-roster-legacy",
    "dbus/test-conn-roster-groups",
    "dbus/test-conn-roster-groups-legacy",
    "dbus/test-contact-factory",
    "dbus/test-contact-messenger",
    "dbus/test-contacts",
    "dbus/test-contacts-avatar",
    "dbus/test-contacts-capabilities",
    "dbus/test-contacts-info",
    "dbus/test-contacts-location",
    "dbus/test-dbus-properties",
    "dbus/test-dbus-proxy-factory",
    "dbus/test-do-nothing",
    "dbus/test-handles",
    "dbus/test-profile-manager",
    "dbus/test-simple-observer",
    "dbus/test-stateful-proxy",
    "dbus/test-streamed-media-chan",
    "dbus/test-text-chan"
    ]

tests_description = [
    ["non-dbus-unit-tests", "Non D-Bus Unit tests",
     non_dbus_tests_env, non_dbus_tests],
    ["dbus-unit-tests", "D-Bus unit tests",
     dbus_tests_env, dbus_tests]]


def main(args):
    print 'Creating tests.xml file.'

    # open file for output
    output_file = open('tests.xml', 'w')

    # add header information
    output_file.write('<?xml version="1.0" encoding="ISO-8859-1"?>\n')
    output_file.write('<testdefinition version="0.1">\n')
    output_file.write('  <suite name="%s-tests">\n' % package_name)
    output_file.write('\n')

    input_line = 'begin'
    last_input_line = None

    for description in tests_description:
        set_name = description[0]
        set_description = description[1]
        cases_env = description[2]
        cases = description[3]

        output_file.write('    <set name="%s" description="%s" feature="%s">\n' % \
                          (set_name, set_description, package_name))
        output_file.write('\n')

        for case in cases:
            output_file.write('      <case name="%s" level="Component" type="Functional" description="%s">\n' % \
                              (case, case))
            output_file.write('        <step expected_result="0">%s %s/%s</step>\n' % \
                              (cases_env, package_dir, case))
            output_file.write('      </case>\n')

        output_file.write('\n')
        output_file.write('      <environments>\n')
        output_file.write('        <hardware>true</hardware>\n')
        output_file.write('      </environments>\n')
        output_file.write('\n')
        output_file.write('    </set>\n')
        output_file.write('\n')

    output_file.write('  </suite>\n')
    output_file.write('</testdefinition>')
    output_file.close()


if __name__ == '__main__':
    main(sys.argv[1:])
    sys.exit(0)
